@@ -1,27 +1,21 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import os
 import sys
-import logging
 from difflib import get_close_matches
 
-from isbntools import (meta, clean, canonical, get_canonical_isbn,
-                       config, registry, quiet_errors)
-from isbntools.dev.bouth23 import b2u3
-from isbntools.dev.lab import fmtbib, fmts
+from isbnlib.dev.helpers import fmtbib, fmts
+
+from ..app import (canonical, clean, config, get_canonical_isbn, meta,
+                   quiet_errors, registry, uprint)
+
+PREFIX = 'isbn_'
 
 
-logging.basicConfig(level=logging.CRITICAL)
-
-WINDOWS = os.name == 'nt'
-
-
-def usage(wservs="wcat|goob|...", ofmts="labels"):
-    sys.stderr.write('Usage: isbn_meta ISBN [%s] [%s] [apikey]\n  '
+def usage(prefix, wservs="wcat|goob|...", ofmts="labels"):
+    sys.stderr.write('Usage: %smeta ISBN [%s] [%s] [apikey]\n  '
                      '...  or try with '
-                     'another service in list!\n' % (wservs, ofmts))
-    sys.exit(1)
+                     'another service in list!\n' % (prefix, wservs, ofmts))
+    return 1
 
 
 def parse_args(args):
@@ -49,10 +43,11 @@ def parse_args(args):
     return (isbn, service, fmt, api)
 
 
-def main():
+def main(args=None, prefix=PREFIX):
     sys.excepthook = quiet_errors
     try:
-        isbn, service, fmt, apikey = parse_args(sys.argv[1:])
+        args = sys.argv[1:] if not args else args[1:]
+        isbn, service, fmt, apikey = parse_args(args)
         if not isbn:
             raise
         service = service if service else 'default'
@@ -63,18 +58,18 @@ def main():
             except:
                 pass
         r = meta(isbn, service)
-        if WINDOWS:
-            # print detects the appropriate codec
-            # (Windows terminal doesn't use UTF-8)
-            print((fmtbib(fmt, r)))
-        else:
-            # stdout gets UTF-8, so that redirection works... (see issue 75)
-            s = fmtbib(fmt, r) + '\n'
-            sys.stdout.write(b2u3(s))
+        uprint((fmtbib(fmt, r)))
     except:
-        providers = list(registry.services.keys())
-        providers.remove('default')
-        available = '|'.join(providers)
-        fmts.remove('labels')
-        ofmts = '|'.join(fmts)
-        usage(available, ofmts)
+        providers = list(registry.services.keys())[:]
+        try:
+            providers.remove('default')
+        except:
+            pass
+        available = '|'.join(sorted(providers))
+        bibf = fmts[:]
+        try:
+            bibf.remove('labels')
+        except:
+            pass
+        ofmts = '|'.join(sorted(bibf))
+        return usage(prefix, available, ofmts)
