@@ -1,13 +1,14 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
+"""Helper function to validate ISBNs from sys.stdin."""
 
-import sys
 import re
-from isbntools import get_isbnlike, get_canonical_isbn
+import sys
+
+from ..app import get_canonical_isbn, get_isbnlike
 
 
 def stdin_validate():
-    """ Helper function to validate ISBNs from sys.stdin
+    """Helper function to validate ISBNs from sys.stdin
 
     It will output all valid ISBNs that receive from input.
 
@@ -16,7 +17,7 @@ def stdin_validate():
     """
     for line in sys.stdin:
         line = line.strip()
-        buf = re.sub("\[|\]|'|-", "", repr(get_isbnlike(line)))
+        buf = re.sub(r"\[|\]|'|-", "", repr(get_isbnlike(line)))
         buf = buf.strip()
         if ',' in buf:
             for b in buf.split(','):
